==> QupZilla-2.1.1.tar.xz: QupZilla-2.1.1/src/plugins/TabManager/translations/ca_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca_ES" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Ajusts del gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Seleccioneu el tipus de vista:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Barra lateral</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Sistema de fitxers local:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Agrupa per</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domini</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Amfitrió</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>Tan&amp;ca les pestanyes marcades</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Finestra %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Mostra el gestor de pestanyes</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.1.tar.xz: QupZilla-2.2.1/src/plugins/TabManager/translations/ca_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca_ES" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Ajusts del gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Seleccioneu el tipus de vista:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Barra lateral</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota:&lt;/span&gt; El tipus &amp;quot;finestra&amp;quot; és recomanable per gestionar moltes finestres / pestanyes.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Usa el connector TabManager com a substitut de la barra de pestanyes principal.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="98"/>
        <source>Local File System:</source>
        <translation>Sistema de fitxers local:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="101"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="104"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="250"/>
        <source>Group by</source>
        <translation>Agrupa per</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="251"/>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="256"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domini</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="261"/>
        <source>&amp;Host</source>
        <translation>&amp;Amfitrió</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="269"/>
        <source>&amp;Show side by side</source>
        <translation>Mostra-le&amp;s una al costat de l&apos;altra</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="275"/>
        <source>&amp;Detach checked tabs</source>
        <translation>&amp;Desprèn les pestanyes marcades</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="276"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Afegeix les pestanyes &amp;marcades a les adreces d&apos;interès</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Close checked tabs</source>
        <translation>Tan&amp;ca les pestanyes marcades</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="528"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Trieu una carpeta per a les adreces d&apos;interès:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="529"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Afegeix les pestanyes seleccionades a les adreces d&apos;interès</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="646"/>
        <source>Window %1</source>
        <translation>Finestra %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="647"/>
        <source>Double click to switch</source>
        <translation>Doble clic per al canvi</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Gestor de pestanyes</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Mostra el gestor de pestanyes</translation>
    </message>
</context>
</TS>
